@@ -1,29 +1,16 @@
 __all__ = ['transpose', 'wrap_row', 'wrap_table', 'show']
 
 # Internal Cell
-try:
-    import pandas
-    has_pandas = lambda: True
-except ModuleNotFoundError:
-    has_pandas = lambda: False
-
-from tabulate import tabulate
+from jedi_toolz.data import handle_data
 from textwrap import fill
 import toolz.curried as tz
 import itertools as it
-from decorator import decorator
+from tabulate import tabulate
+from typing import Union
 
-@decorator
-def handle_pandas(func, *args, **kwargs):
-    orig = [arg for arg in args]
-    data = orig[0]
-    if has_pandas() and isinstance(data, pandas.DataFrame):
-        data = data.to_dict("records")
-    updated = [data if num == 0 else arg for num, arg in enumerate(orig)]
-    return func(*updated, **kwargs)
-
-@handle_pandas
+@handle_data
 def text_table(data, print_out=True, **tabulate_args):
+    """A partial version of the tabulate.tabulate function."""
     defaults = {
         "tablefmt": "fancy_grid",
         "floatfmt": ",.2f",
@@ -36,12 +23,16 @@ def text_table(data, print_out=True, **tabulate_args):
     else:
         return tab(data)
 
-@handle_pandas
+@handle_data
 def head(data, limit=100):
+    """Returns the first {limit} records of a Table."""
     return list(tz.take(limit, data))
 
-@handle_pandas
+@handle_data
 def transpose(data):
+    """Transposes a table (list of dicts) such that columns are
+    rows and rows are columns.
+    """
     count = it.count(1)
     row_num = lambda: next(count)
     header = lambda d: list(d.keys())
@@ -56,6 +47,8 @@ def transpose(data):
     )
 
 def wrap_row(row, col_width):
+    """Returns a string version of a dict with long values split
+    into lines."""
     result = {}
     for k, v in row.items():
         new_k = fill(str(k), col_width)
@@ -63,7 +56,7 @@ def wrap_row(row, col_width):
         result[new_k] = new_v
     return result
 
-@handle_pandas
+@handle_data
 def wrap_table(data, col_width):
     """Takes a list of dicts and wraps the keys and values by the
     specified col_width."""
@@ -72,8 +65,9 @@ def wrap_table(data, col_width):
 def text_width(text):
     return max(len(line) for line in text.splitlines())
 
-@handle_pandas
+@handle_data
 def get_text(data, limit, vert, col_width):
+    """Returns the text to be printed by text_table."""
     return tz.pipe(
         head(data, limit),
         lambda table: transpose(table) if vert else table,
@@ -82,12 +76,25 @@ def get_text(data, limit, vert, col_width):
     )
 
 @tz.curry
-@handle_pandas
-def show(data, limit=30, vert=False, col_width=15, table_width=80):
+@handle_data
+def show(data, limit=30, vert=False, col_width=15, table_width=80,
+    print_out: bool=True) -> str:
+    """Prints an ascii table using the tabulate.tabulate function.
+    col_width and table_width parameters can be provided to customize
+    the width and appearance of the table.
+
+    vert = True will transpose the data (columns are rows and rows
+    are columns).
+
+    limit can be used to determine the number of rows printed.
+    """
     orig = get_text(data, limit, vert, col_width)
     if text_width(orig) <= table_width:
-        print(orig)
-        return None
+        if print_out:
+            print(orig)
+            return ""
+        else:
+            return orig
     else:
         good = get_text(data, limit=1, vert=True, col_width=col_width)
         msg = (
@@ -100,6 +107,8 @@ def show(data, limit=30, vert=False, col_width=15, table_width=80):
         new = get_text(data, n, True, col_width)
         if text_width(new) <= table_width:
             good = new
-        else:
+        elif print_out:
             print(good)
-            return None
\ No newline at end of file
+            return ""
+        elif not print_out:
+            return good
